/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2007,2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: GabonClass.java 2438 2010-02-24 16:20:30Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.test;

import java.rmi.RemoteException;

import javax.rmi.PortableRemoteObject;

import org.ow2.cmi.annotation.ArrayProperty;
import org.ow2.cmi.annotation.Cluster;
import org.ow2.cmi.annotation.Policy;
import org.ow2.cmi.annotation.Properties;
import org.ow2.cmi.annotation.SimpleProperty;
import org.ow2.cmi.annotation.Strategy;
import org.ow2.cmi.lb.strategy.LocalPreference;
import org.ow2.util.pool.annotation.Pool;

/**
 * Simple class used in test.
 *
 * @author Florent Benoit
 */
@Cluster(name = "example-cluster", pool = @Pool(max = 2))
@Policy(LatestPolicy.class)
@Strategy(LocalPreference.class)
@Properties(simpleProperties = {
        @SimpleProperty(name = "author", value = "eyindanga"),
        @SimpleProperty(name = "year", value = "2008") }, arrayProperties = {
        @ArrayProperty(name = "prop3", values = "true"),
        @ArrayProperty(name = "prop4", values = { "java.util.LinkedList",
                "java.util.ArrayList" }),
        @ArrayProperty(name = "prop5", values = { "http://www.ow2.org" }) })
public class GabonClass extends PortableRemoteObject implements GabonItf {

    private static final String DESCRIPTION = "Gabon is a country in west central Africa sharing borders \n"
            + "with Equatorial Guinea, Cameroon, Republic of the Congo and the Gulf of Guinea. \n "
            + "It got independent from France on August 17, 1960."
            + "In the early 1990s, Gabon introduced a multi party system and a new democratic constitution that allowed  \n"
            + "for a more transparent electoral process and reformed many governmental institutions.  \n"
            + "A small population, abundant natural resources,  \n"
            + "and foreign private investment have helped make Gabon one of the most prosperous countries in the region,  \n"
            + "with the highest HDI in Sub-Saharan Africa \n";
    /**
     * Politic capital
     */
    private static final String POLITIC_CAPITAL = "Libreville";
    /**
     * Economic capital
     */
    private static final String ECONOMIC_CAPITAL = "Port-Gentil";
    /**
     * GDP.
     */
    private static final String GNP = "2004: 5.06 Billions dollar, rank 123/177";

    private String gnp = GNP;

    /**
     * GDP.
     */
    private static final String HDI = "2004: 0.635, rank 123/177";
    /**
     * HDI.
     */
    private String hdi = HDI;

    /**Constructor.
     * @param gnp
     * @param hdi
     * @throws RemoteException
     */
    public GabonClass(final String gnp, final String hdi) throws RemoteException {
        super();
        this.hdi = hdi;
        this.gnp = gnp;
    }

    public GabonClass() throws RemoteException {
        super();
    }


    /*
     * (non-Javadoc)
     *
     * @see org.ow2.cmi.test.GabonItf#getDescription()
     */
    public String getDescription() throws RemoteException {
        return DESCRIPTION;
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.cmi.test.GabonItf#getEconomicCapital()
     */
    public String getEconomicCapital() throws RemoteException {
        return ECONOMIC_CAPITAL;
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.cmi.test.GabonItf#getGDP()
     */
    public String getHDI() throws RemoteException {
        // TODO Auto-generated method stub
        return hdi;
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.cmi.test.GabonItf#getGNP()
     */
    public String getGNP() throws RemoteException {
        return gnp;

    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.cmi.test.GabonItf#getPoliticCapital()
     */
    public String getPoliticCapital() throws RemoteException {
        return POLITIC_CAPITAL;
    }

}
